@@ -13,6 +13,8 @@
 #' \ifelse{latex}{\out{\href{https://rfhb.github.io/ctrdata/#id_2-script-to-automatically-copy-users-query-from-web-browser}{here}}}{\href{https://rfhb.github.io/ctrdata/#id_2-script-to-automatically-copy-users-query-from-web-browser}{here}}.
 #' Can also contain a query term such as from
 #' \link{dbQueryHistory}()["query-term"].
+#' Can also be an identifier of a trial, which based on its
+#' format will indicate to which register it relates.
 #'
 #' @param register Optional name of register (one of "EUCTR", "CTGOV2"
 #' "ISRCTN" or "CTIS") in case `url` is a query term but not a full URL
@@ -26,7 +28,6 @@
 #' `url` to \link{ctrOpenSearchPagesInBrowser}.
 #'
 #' @importFrom clipr read_clip
-#' @importFrom tibble as_tibble
 #'
 #' @examples
 #'
@@ -48,6 +49,7 @@
 #'     )
 #' )
 #'
+#' # other examples
 #' ctrGetQueryUrl("https://www.clinicaltrialsregister.eu/ctr-search/trial/2007-000371-42/results")
 #' ctrGetQueryUrl("https://euclinicaltrials.eu/ctis-public/view/2022-500041-24-00")
 #' ctrGetQueryUrl("https://classic.clinicaltrials.gov/ct2/show/NCT01492673?cond=neuroblastoma")
@@ -55,6 +57,13 @@
 #' ctrGetQueryUrl("https://clinicaltrials.gov/study/NCT01467986?aggFilters=ages:child")
 #' ctrGetQueryUrl("https://www.isrctn.com/ISRCTN70039829")
 #'
+#' # using identifiers of single trials
+#' ctrGetQueryUrl("70039829")
+#' ctrGetQueryUrl("ISRCTN70039829")
+#' ctrGetQueryUrl("NCT00617929")
+#' ctrGetQueryUrl("2022-501142-30-00")
+#' ctrGetQueryUrl("2012-003632-23")
+#'
 ctrGetQueryUrl <- function(
     url = "",
     register = "") {
@@ -118,8 +127,27 @@ ctrGetQueryUrl <- function(
     "NONE"
   )
 
+  # identify register from trial identifier
+  # added after CTGOV was decomissioned
+  if (registerFromUrl == "NONE" &&
+      register == "") {
+    registerFromUrl <- switch(
+      c(as.character(1:5)[sapply(
+        c(regCtgov2, regCtis, regEuctr, regIsrctn, paste0("ISRCTN", regIsrctn)),
+        function(r) grepl(paste0("^", r, "$"), url))], "")[1],
+      "1" = "CTGOV2",
+      "2" = "CTIS",
+      "3" = "EUCTR",
+      "4" = "ISRCTN",
+      "5" = "ISRCTN",
+      "NONE"
+    )
+  }
+
   # check parameters expectations
-  if (register != "" && registerFromUrl != "NONE" && register != registerFromUrl) {
+  if (register != "" &&
+      registerFromUrl != "NONE" &&
+      register != registerFromUrl) {
     stop("ctrGetQueryUrl(): 'url' and / or 'register' mismatch, url: '",
          deparse(url), "', register: '", deparse(register), "'",
          call. = FALSE
@@ -169,6 +197,11 @@ ctrGetQueryUrl <- function(
     if (endsWith(url, ".*/results")) {
       queryterm <- paste0(queryterm)
     }
+    queryterm <- sub(
+      paste0("^(", regEuctr, ")$"),
+      'query=\\1',
+      queryterm
+    )
 
     # inform user
     if (grepl("^http", queryterm) && queryterm == url) stop(
@@ -266,6 +299,11 @@ ctrGetQueryUrl <- function(
         "this as 'url'."
       )
     }
+    queryterm <- sub(
+      paste0("(^", regIsrctn, "$)|^ISRCTN(", regIsrctn, "$)"),
+      'q=\\1',
+      queryterm
+    )
 
     # return
     return(outdf(queryterm, register))
@@ -277,7 +315,7 @@ ctrGetQueryUrl <- function(
     # extract search query
     queryterm <- sub(
       paste0(
-        "(.*/study/", regCtgov, 
+        "(.*/study/", regCtgov,
         "/?[?]|.*/(expert-search|search)/?[?][&]?)([a-z]+.*$)"),
       "\\3", url
     )
@@ -295,6 +333,11 @@ ctrGetQueryUrl <- function(
       queryterm <-
         paste0(sub(paste0(".*study/(", regCtgov2, ").*"), "id=\\1", url))
     }
+    queryterm <- sub(
+      paste0("^(", regCtgov2, ")$"),
+      'term=\\1',
+      queryterm
+    )
 
     # inform user
     if (grepl("^http", queryterm) && queryterm == url) stop(
@@ -330,7 +373,12 @@ ctrGetQueryUrl <- function(
 
     # if viewing a single trial
     queryterm <- sub(
-     "https://euclinicaltrials.eu/ctis-public/view/([-0-9]+)",
+      "https://euclinicaltrials.eu/ctis-public/view/([-0-9]+)",
+      'searchCriteria={"number":"\\1"}',
+      queryterm
+    )
+    queryterm <- sub(
+      paste0("^(", regCtis, ")$"),
       'searchCriteria={"number":"\\1"}',
       queryterm
     )
